@@ -2,7 +2,7 @@ from abc import ABCMeta, abstractmethod
 from typing import Dict, Union
 
 from nidhoggr.core.response import StatusResponse, TextureStatusResponse, ErrorResponse
-from nidhoggr.core.texture import TextureType, TextureItem, TextureUploadRequest, TextureRequest
+from nidhoggr.core.texture import TextureUploadRequest, TextureRequest, TextureResponse
 from nidhoggr.core.user import User
 
 
@@ -10,7 +10,7 @@ class BaseTextureRepo(metaclass=ABCMeta):
     variant: str
 
     @abstractmethod
-    def get(self, *, request: TextureRequest) -> Union[ErrorResponse, Dict[TextureType, TextureItem]]:
+    def get(self, *, request: TextureRequest) -> Union[ErrorResponse, TextureResponse]:
         pass
 
     @abstractmethod
