@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Optional, Dict, List
+from typing import Optional, Dict, List, Tuple
 
 from pydantic.main import BaseModel
 
@@ -39,7 +39,7 @@ class TextureUploadRequest(BaseModel):
 
 
 class TextureResponse(BaseModel):
-    textures: Dict[TextureType, TextureItem]
+    textures: List[Tuple[TextureType, TextureItem]]
 
     class Config:
         allow_mutation = False
